==> nx-libs_3.5.99.16.orig.tar.gz: nx-libs-3.5.99.16/nx-X11/programs/Xserver/hw/nxagent/Clipboard.h <==
/**************************************************************************/
/*                                                                        */
/* Copyright (c) 2001, 2011 NoMachine (http://www.nomachine.com)          */
/* Copyright (c) 2008-2014 Oleksandr Shneyder <o.shneyder@phoca-gmbh.de>  */
/* Copyright (c) 2011-2016 Mike Gabriel <mike.gabriel@das-netzwerkteam.de>*/
/* Copyright (c) 2014-2016 Mihai Moldovan <ionic@ionic.de>                */
/* Copyright (c) 2014-2016 Ulrich Sibiller <uli42@gmx.de>                 */
/* Copyright (c) 2015-2016 Qindel Group (http://www.qindel.com)           */
/*                                                                        */
/* NXAGENT, NX protocol compression and NX extensions to this software    */
/* are copyright of the aforementioned persons and companies.             */
/*                                                                        */
/* Redistribution and use of the present software is allowed according    */
/* to terms specified in the file LICENSE which comes in the source       */
/* distribution.                                                          */
/*                                                                        */
/* All rights reserved.                                                   */
/*                                                                        */
/* NOTE: This software has received contributions from various other      */
/* contributors, only the core maintainers and supporters are listed as   */
/* copyright holders. Please contact us, if you feel you should be listed */
/* as copyright holder, as well.                                          */
/*                                                                        */
/**************************************************************************/

#ifndef __Clipboard_H__
#define __Clipboard_H__

/*
 * Queried at clipboard initialization.
 */

typedef struct _XFixesAgentInfo
{
  int Opcode;
  int EventBase;
  int ErrorBase;
  int Initialized;

} XFixesAgentInfoRec;

extern XFixesAgentInfoRec nxagentXFixesInfo;

/*
 * Create the NX_CUT_BUFFER_CLIENT atom and
 * initialize the required property to exchange
 * data with the X server.
 */

extern int nxagentInitClipboard(WindowPtr pWindow);

/*
 * Called whenever a client or a window is
 * destroyed to let the clipboard code to
 * release any pointer to the referenced
 * structures.
 */

extern void nxagentClearClipboard(ClientPtr pClient, WindowPtr pWindow);

extern void nxagentSetSelectionOwner(Selection *pSelection);
extern int nxagentConvertSelection(ClientPtr client, WindowPtr pWin, Atom selection,
                                      Window requestor, Atom property, Atom target, Time time);

void nxagentClearSelection();
void nxagentRequestSelection();
void nxagentNotifySelection();

#endif /* __Clipboard_H__ */

==> nx-libs_3.5.99.23.orig.tar.gz: nx-libs-3.5.99.23/nx-X11/programs/Xserver/hw/nxagent/Clipboard.h <==
/**************************************************************************/
/*                                                                        */
/* Copyright (c) 2001, 2011 NoMachine (http://www.nomachine.com)          */
/* Copyright (c) 2008-2014 Oleksandr Shneyder <o.shneyder@phoca-gmbh.de>  */
/* Copyright (c) 2011-2016 Mike Gabriel <mike.gabriel@das-netzwerkteam.de>*/
/* Copyright (c) 2014-2016 Mihai Moldovan <ionic@ionic.de>                */
/* Copyright (c) 2014-2016 Ulrich Sibiller <uli42@gmx.de>                 */
/* Copyright (c) 2015-2016 Qindel Group (http://www.qindel.com)           */
/*                                                                        */
/* NXAGENT, NX protocol compression and NX extensions to this software    */
/* are copyright of the aforementioned persons and companies.             */
/*                                                                        */
/* Redistribution and use of the present software is allowed according    */
/* to terms specified in the file LICENSE which comes in the source       */
/* distribution.                                                          */
/*                                                                        */
/* All rights reserved.                                                   */
/*                                                                        */
/* NOTE: This software has received contributions from various other      */
/* contributors, only the core maintainers and supporters are listed as   */
/* copyright holders. Please contact us, if you feel you should be listed */
/* as copyright holder, as well.                                          */
/*                                                                        */
/**************************************************************************/

#ifndef __Clipboard_H__
#define __Clipboard_H__

/*
 * Queried at clipboard initialization.
 */

typedef struct _XFixesAgentInfo
{
  int Opcode;
  int EventBase;
  int ErrorBase;
  int Initialized;
} XFixesAgentInfoRec;

extern XFixesAgentInfoRec nxagentXFixesInfo;

/*
 * Create the NX_SELTRANS_FROM_AGENT atom and
 * initialize the required property to exchange
 * data with the X server.
 */

extern Bool nxagentInitClipboard(WindowPtr pWindow);

/*
 * Called whenever a client or a window is
 * destroyed to let the clipboard code to
 * release any pointer to the referenced
 * structures.
 */

extern void nxagentClearClipboard(ClientPtr pClient, WindowPtr pWindow);

extern void nxagentSetSelectionOwner(Selection *pSelection);
extern int nxagentConvertSelection(ClientPtr client, WindowPtr pWin, Atom selection,
                                      Window requestor, Atom property, Atom target, Time time);

void nxagentClearSelection();
void nxagentRequestSelection();
void nxagentHandleSelectionNotifyFromXServer();

int nxagentFindCurrentSelectionIndex(Atom sel);
#endif /* __Clipboard_H__ */
